.. :changelog:

History
-------

0.1.0 (2017-12-02)
++++++++++++++++++

* First release on PyPI.
* TimeStampedLabelModel abstract model class
* UserRelatedField for use in DRF serializers
* DisplayChoiceField for use in DRF serializers
* ContentRelatedField for use in DRF serializers
* DefaultRouter that allows you to extend other routers
* ModelMixinTestCase that allows you to test abstract model classes

0.2.0 (2017-12-31)
++++++++++++++++++

`0.2.0 Changelog <https://github.com/chopdgd/django-genomix/compare/v0.1.0...v0.2.0>`_

* Added utils function to retrieve data from a URL
* Added utils function to retrieve compressed data from a URL

0.3.0 (2018-01-04)
++++++++++++++++++

`0.3.0 Changelog <https://github.com/chopdgd/django-genomix/compare/v0.2.0...v0.3.0>`_

* DisplayChoiceFilter for use in django_filters. Filter by diplay fields for a choice field in a REST API

0.4.0 (2018-01-05)
++++++++++++++++++

`0.4.0 Changelog <https://github.com/chopdgd/django-genomix/compare/v0.3.0...v0.4.0>`_

* Improved docs
* Beta release

0.4.1 (2018-01-09)
++++++++++++++++++

`0.4.1 Changelog <https://github.com/chopdgd/django-genomix/compare/v0.4.0...v0.4.1>`_

* DisplayChoiceFilter fixed coerce method to handle Choices with different display values.

0.5.0 (2018-02-09)
++++++++++++++++++

`0.5.0 Changelog <https://github.com/chopdgd/django-genomix/compare/v0.4.1...v0.5.0>`_

* Updated requirements to the latest.

0.6.0 (2018-04-07)
++++++++++++++++++

`0.6.0 Changelog <https://github.com/chopdgd/django-genomix/compare/v0.5.0...v0.6.0>`_

* Added support for Django 2.0 and Python3.6
* Dropped support for Django <1.11 and Python 2.7, 3.3, 3.4

0.6.1 (2018-04-18)
++++++++++++++++++

`0.6.1 Changelog <https://github.com/chopdgd/django-genomix/compare/v0.6.0...v0.6.1>`_

* Upgraded 3rd party libs

0.6.2 (2018-05-16)
++++++++++++++++++

`0.6.2 Changelog <https://github.com/chopdgd/django-genomix/compare/v0.6.1...v0.6.2>`_

* Updated setup.py to read install_requires from requirements.txt

0.6.3 (2018-08-13)
++++++++++++++++++

`0.6.3 Changelog <https://github.com/chopdgd/django-genomix/compare/v0.6.2...v0.6.3>`_

* Updated 3rd party requirements.  Some requirements had changed so it was causing failures

0.6.4 (2018-10-29)
++++++++++++++++++

`0.6.4 Changelog <https://github.com/chopdgd/django-genomix/compare/v0.6.3...v0.6.4>`_

* Updated deps and adjusted for new flake8 reqs

0.6.5 (2019-02-07)
++++++++++++++++++

`0.6.5 Changelog <https://github.com/chopdgd/django-genomix/compare/v0.6.4...v0.6.5>`_

* Updated deps

0.6.6 (2019-04-10)
++++++++++++++++++

`0.6.6 Changelog <https://github.com/chopdgd/django-genomix/compare/v0.6.5...v0.6.6>`_

* Updated deps
* Updated travis to use xenial distribution.  Django 2.1 dropped support for SQLite < 3.8.3

0.6.7 (2019-05-30)
++++++++++++++++++

`0.6.7 Changelog <https://github.com/chopdgd/django-genomix/compare/v0.6.6...v0.6.7>`_

* Updated deps

0.6.8 (2019-07-26)
++++++++++++++++++

`0.6.8 Changelog <https://github.com/chopdgd/django-genomix/compare/v0.6.7...v0.6.8>`_

* Updated deps

0.6.9 (2019-08-09)
++++++++++++++++++

`0.6.9 Changelog <https://github.com/chopdgd/django-genomix/compare/v0.6.8...v0.6.9>`_

* Updated deps
